@@ -24,6 +24,8 @@ class Therver : public cliser::Server{
 	friend class ClientDisconnectedMessage;
 	friend class KillIdleCastsMessage;
 
+	T_ClientsList waitingForListeningClients;
+
 	T_CastsList casts;
 
 	static inline ting::u32 DIdleCastDuration(){
@@ -93,6 +95,11 @@ private:
 
 	void KillIdleCasts();
 
+	void MoveClientToIdleState(ting::Ref<Client>& c);
+
+	void MoveWaitingListenersToCast();
+	void RemoveClientFromWaitingListenersList(ting::Ref<Client>& c);
+
 public:
 	void PushRegisterResultMessage(Client::ERegisterRes result, ting::Ref<Client> c);
 };
