@@ -67,7 +67,10 @@ void Lib::PlayChannel(ting::Ref<Channel> ch){
 		return;//already playing
 	this->thread.chPoolToAdd.push_back(ch);//queue channel to be added to playing pool
 	ch->isPlaying = true;//mark channel as playing
-};
+
+	//in case the thread is hanging on the queue, wake it up by sending the nop message.
+	this->thread.PushNopMessage();
+}
 
 
 
@@ -130,6 +133,14 @@ void Lib::SoundThread::Run(){
 			}
 		}
 
+		//If there is nothing to play then just hang on the message queue.
+		//When new channel is added to the list a NOP message will be sent to
+		//the queue.
+		if(this->chPool.size() == 0){
+			this->queue.GetMsg()->Handle();
+			continue;
+		}
+
 		//mix channels to mixbuf
 		for(TChIter i = this->chPool.begin(); i != this->chPool.end();){
 			if((*i)->MixToMixBuf(mixBuf)){
